Managing Data
=============

.. toctree::
  :maxdepth: 2
  :hidden:


  ../api/tom_dataproducts/views
  plotting_data
  customizing_data_processing


:doc:`Creating Plots from TOM Data <plotting_data>` - Learn how to create plots using plot.ly and your TOM
data to display anywhere in your TOM.

:doc:`Adding Custom Data Processing <customizing_data_processing>` - Learn how you can process data into your
TOM from uploaded data products.
